==> eiffelstudio-16.05.tar: F_code/C2/po93.c <==
/*
 * Code for class PO_FILE_HEADERS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po93.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_HEADERS}.make */
void F130_1532 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	tr1 = RTMS_EX_H("",0,0);
	F129_1527(Current, tr1);
	{
		static EIF_TYPE_INDEX typarr0[] = {677,896,896,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F678_4256(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_HEADERS}.add_header */
void F130_1536 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,tr2);
	RTLR(4,arg1);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr2 = F888_6652(RTCW(arg2));
	tr3 = F888_6652(RTCW(arg1));
	F678_4301(RTCW(tr1), tr2, tr3);
	RTLE;
}

/* {PO_FILE_HEADERS}.to_string */
EIF_REFERENCE F130_1538 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R1934[Dtype(tr1)-671])(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	F678_4294(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F672_4155(RTCW(tr1));
	tr1 = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F888_6592(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	for (;;) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tb1 = F678_4289(RTCW(tr1));
		if (tb1) break;
		F897_7007(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F678_4267(RTCW(tr1));
		F897_6982(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H(": ",2,14880);
		tr1 = F888_6651(tr1);
		F897_6979(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F678_4266(RTCW(tr1));
		F897_6982(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H("\\n",2,23662);
		tr1 = F888_6651(tr1);
		F897_6979(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr2 = (EIF_REFERENCE) eif_builtin_ANY_twin (loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1930[Dtype(tr1)-282])(RTCW(tr1), tr2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		F678_4295(RTCW(tr1));
	}
	RTLE;
	return (EIF_REFERENCE) F129_1530(Current);
}

/* {PO_FILE_HEADERS}.headers */
EIF_REFERENCE F130_1539 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


void EIF_Minit93 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C2/po93.c <==
/*
 * Code for class PO_FILE_HEADERS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po93.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_HEADERS}.make */
void F130_1562 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("",0,0);
	tr1 = F939_6880(tr1);
	tr2 = RTMS_EX_H("",0,0);
	F129_1557(Current, tr1, tr2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,740,0xFF01,947,0xFF01,947,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F741_4554(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_HEADERS}.add_header */
void F130_1566 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,tr2);
	RTLR(4,arg1);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr2 = F939_6881(RTCW(arg2));
	tr3 = F939_6881(RTCW(arg1));
	F741_4599(RTCW(tr1), tr2, tr3);
	RTLE;
}

/* {PO_FILE_HEADERS}.to_string */
EIF_REFERENCE F130_1568 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R1970[Dtype(tr1)-672])(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	F741_4592(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F673_4272(RTCW(tr1));
	tr1 = RTLNS(eif_new_type(947, 0x01).id, 947, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F939_6821(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	for (;;) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tb1 = F741_4587(RTCW(tr1));
		if (tb1) break;
		F948_7255(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F741_4565(RTCW(tr1));
		F948_7230(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H(": ",2,14880);
		tr1 = F939_6880(tr1);
		F948_7227(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F741_4564(RTCW(tr1));
		F948_7230(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H("\\n",2,23662);
		tr1 = F939_6880(tr1);
		F948_7227(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr2 = F1_14(loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1966[Dtype(tr1)-282])(RTCW(tr1), tr2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		F741_4593(RTCW(tr1));
	}
	RTLE;
	return (EIF_REFERENCE) F129_1560(Current);
}

/* {PO_FILE_HEADERS}.headers */
EIF_REFERENCE F130_1569 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


void EIF_Minit93 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
